---
title: Introduction to Quasar Framework
---

![Quasar - Empowering your websites and apps](https://cdn.quasar-framework.org/img/responsive.png)

## What is Quasar?
Quasar (pronounced `/ˈkweɪ.zɑɹ/`) is an MIT licensed open-source Vue.js based framework, which allows you as a web developer to quickly create responsive++ websites/apps in many flavours:
* SPAs (Single Page App)
* SSR (Server-side Rendered App) (+ optional PWA client takeover)
* PWAs (Progressive Web App)
* Mobile Apps (Android, iOS, …) through Apache Cordova
* Multi-platform Desktop Apps (using Electron)

Quasar's motto is: **write code once and simultaneously deploy it** as a website, a Mobile App and/or an Electron App. Yes, one codebase for all of them, helping you develop an app in record time by using a state of the art CLI and backed by best-practice, blazing fast Quasar web components.

When using Quasar, you won't need additional heavy libraries like Hammerjs, Momentjs or Bootstrap. It's got those needs covered internally, and all with a small footprint!

## Why Quasar?
Because of the simplicity and power offered to you out of the box. Quasar, with its CLI, is packed full of features, all built to make your developer life easier.

Below is a non-exhaustive list of Quasar's great aspects and features.

#### All Platforms in One Go
One authoritative source of code for all platforms, simultaneously: responsive desktop/mobile websites (SPA, SSR + SPA client takeover, SSR + PWA client takeover), PWAs (Progressive Web Apps), mobile apps (that look native) and multi-platform desktop apps (through Electron).

#### The largest sets of Top-Class, fast and responsive web components
There’s a component for almost every web development need within Quasar. Each of Quasar's components is carefully crafted to offer you the best possible experience for your users. Quasar is **designed with performance & responsiveness in mind** – so the overhead of using Quasar is barely noticeable. This attention to performance and good design is something that gives us special pride.

#### Best practices integrated by default
Quasar was also built to encourage developers to follow web development best practices. To do this, Quasar is packed full of great features out of the box.
 - HTML/CSS/JS minification
 - Cache busting
 - Tree shaking
 - Sourcemapping
 - Code-splitting with lazy loading
 - ES6 transpiling
 - Linting code
 - Accessibility features

Quasar takes care of all these web develoment best parctices and more - **with no configuration needed**.

#### Full RTL Support
RTL (right to left) support for both Quasar components & the developer’s own code. Developer-written website/app CSS code gets automatically converted to RTL if an RTL language pack is used.

#### Progressively migrate your existing project
Quasar offers a UMD (Unified Module Definition) version, which means developers can add a CSS and JS HTML tag into their existing project and they’re ready to use it. No build step is required.

#### Unparalleled developer experience through Quasar CLI
When using Quasar’s CLI, developers benefit from:

 - State preserving hot module reload (HMR) - when making changes to app source code, no matter if it’s a website, PWA, a Mobile App (directly on a phone or on an emulator) or an Electron app. Developers simply change their code, save the changes and then watch it get updated on the fly, without the need of any page refresh.
 - State preserving compilation error overlay
 - Lint-on-save with ESLint – if developers like linting their code
 - ES6 code transpiling
 - Sourcemaps
 - Changing build options doesn’t require a manual reload of the dev server
 - And many more leading-edge developer tools and techniques

#### Get up to speed fast
The top-class project intitialization feature of the CLI makes getting started very easy for you, as a developer. You can get your idea to reality in record time. In other words, Quasar does the heavy lifting for you, so you are free to focus on your features and not on boilerplate.

#### Awesome ever-growing community
When developers encounter a problem they can’t solve, they can visit the Quasar [forum](https://forum.quasar-framework.org/) or our [Discord chat server](https://discord.gg/5TDhbDg). The community is there to help you. You can also get updates on new versions and features by following us on [Twitter](https://twitter.com/quasarframework). You can also get special service as a [Patreon](https://www.patreon.com/quasarframework) and help make sure Quasar stays relevant for you in the future too!

#### A wide range of platform support
Google Chrome, Firefox, IE11/Edge, Safari, Opera, iOS, Android, Windows Phone, Blackberry, MacOS, Linux, Windows.

#### Quasar Language Packs
Quasar comes equipped with over 40 language packs out of the box. On top of that, if your language pack is missing, it takes just 5 minutes to add it.

#### Great documentation
And finally, it’s worth mentioning the significant amount of time taken to write great, bloat-free, focused and complete documentation, so that developers can quickly pick up Quasar. We put special effort into our documentation to be sure there is no confusion.

## Underlying technologies
[Vue](https://vuejs.org/), [Babel](https://babeljs.io/), [Webpack](https://webpack.js.org/), [Cordova](https://cordova.apache.org/), [Electron](https://electronjs.org/).

Except for Vue, which takes half a day to pick up and will change you forever, there is no requirement for you to know the other technologies. They are all integrated and configured in Quasar for you.

## Get started in under a minute
Having said this, let's [get started](/start)! You'll be running a website or app in under a minute.
